==> selenium-selenium-4.38.0.gh.tar.gz: selenium-selenium-4.38.0/java/test/org/openqa/selenium/grid/web/ClassPathResourceTest.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.grid.web;

import static org.assertj.core.api.Assertions.assertThat;

import com.google.common.collect.ImmutableSet;
import java.net.URL;
import java.util.Optional;
import java.util.Set;
import java.util.stream.Collectors;
import org.junit.jupiter.api.Test;

class ClassPathResourceTest {

  @Test
  void shouldGetASingleFile() {
    URL res = getClass().getResource("/test/org/openqa/selenium/grid/web");
    assertThat(res).isNotNull();

    Resource resource = new ClassPathResource(res, "test/org/openqa/selenium/grid/web");
    assertThat(resource.isDirectory()).isTrue();

    Optional<Resource> found = resource.get("packaged-file.txt");
    assertThat(found).isPresent();
  }

  @Test
  void shouldComplainIfResourceDoesNotExist() {}

  @Test
  void shouldReportDirectoriesAsDirectories() {}

  @Test
  void shouldListContentsOfDirectoriesIfInSameJar() {
    URL res = getClass().getResource("/test/org/openqa/selenium/grid/web");
    assertThat(res).isNotNull();

    Resource resource = new ClassPathResource(res, "test/org/openqa/selenium/grid/web");
    assertThat(resource.isDirectory()).isTrue();

    Set<String> names = resource.list().stream().map(Resource::name).collect(Collectors.toSet());

    assertThat(names).isEqualTo(ImmutableSet.of("packaged-file.txt"));
  }
}

==> selenium-selenium-4.40.0.gh.tar.gz: selenium-selenium-4.40.0/java/test/org/openqa/selenium/grid/web/ClassPathResourceTest.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.grid.web;

import static org.assertj.core.api.Assertions.assertThat;

import java.net.URL;
import java.util.Optional;
import java.util.Set;
import java.util.stream.Collectors;
import org.junit.jupiter.api.Test;

class ClassPathResourceTest {

  @Test
  void shouldGetASingleFile() {
    URL res = getClass().getResource("/test/org/openqa/selenium/grid/web");
    assertThat(res).isNotNull();

    Resource resource = new ClassPathResource(res, "test/org/openqa/selenium/grid/web");
    assertThat(resource.isDirectory()).isTrue();

    Optional<Resource> found = resource.get("packaged-file.txt");
    assertThat(found).isPresent();
  }

  @Test
  void shouldComplainIfResourceDoesNotExist() {}

  @Test
  void shouldReportDirectoriesAsDirectories() {}

  @Test
  void shouldListContentsOfDirectoriesIfInSameJar() {
    URL res = getClass().getResource("/test/org/openqa/selenium/grid/web");
    assertThat(res).isNotNull();

    Resource resource = new ClassPathResource(res, "test/org/openqa/selenium/grid/web");
    assertThat(resource.isDirectory()).isTrue();

    Set<String> names = resource.list().stream().map(Resource::name).collect(Collectors.toSet());

    assertThat(names).containsExactly("packaged-file.txt");
  }
}
